@@ -4,8 +4,8 @@ use warnings;
 
 package Dist::Iller::Config::Author::CSSON;
 
-our $VERSION = '0.0202'; # VERSION
 # ABSTRACT: Dist::Iller config
+our $VERSION = '0.0300';
 
 use Moose;
 use namespace::autoclean;
@@ -48,7 +48,10 @@ has homepage => (
     is => 'rw',
     isa => Str,
     lazy => 1,
-    default => sub { sprintf 'https://metacpan.org/release/' . shift->distribution_name },
+    default => sub {
+        my $self = shift;
+        $self->has_distribution_name ? sprintf 'https://metacpan.org/release/%s', $self->distribution_name : undef;
+    },
     documentation_default => q{https://metacpan.org/release/[distribution_name]},
     documentation => q{URL to the distribution's homepage.},
 );
@@ -89,7 +92,7 @@ has travis_perl_max => (
 );
 
 
-with 'Dist::Iller::Role::Config';
+with 'Dist::Iller::Config';
 
 sub build_file {
     my $self = shift;
@@ -156,7 +159,7 @@ Dist::Iller::Config::Author::CSSON - Dist::Iller config
 
 =head1 VERSION
 
-Version 0.0202, released 2016-02-03.
+Version 0.0300, released 2016-02-06.
 
 
 
@@ -435,6 +438,36 @@ Dist::Iller::Config::Author::Csson is a L<Dist::Iller> configuration. The plugin
 
 =end markdown
 
+=head2 main_module
+
+=begin HTML
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>The package name</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Override this attribute when there's more than one config in a distribution. It uses the main_module's sharedir location for the config files.</p>
+
+=end HTML
+
+=begin markdown
+
+<table cellpadding="0" cellspacing="0">
+<tr>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a></td>
+    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional, default: <code>The package name</code></td>
+    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
+</tr>
+</table>
+
+<p>Override this attribute when there's more than one config in a distribution. It uses the main_module's sharedir location for the config files.</p>
+
+=end markdown
+
 =head2 splint
 
 =begin HTML
@@ -506,36 +539,6 @@ Dist::Iller::Config::Author::Csson is a L<Dist::Iller> configuration. The plugin
 
 =end markdown
 
-=head2 main_module
-
-=begin HTML
-
-<table cellpadding="0" cellspacing="0">
-<tr>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a></td>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional</td>
-    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
-</tr>
-</table>
-
-<p></p>
-
-=end HTML
-
-=begin markdown
-
-<table cellpadding="0" cellspacing="0">
-<tr>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;"><a href="https://metacpan.org/pod/Types::Standard#Str">Str</a></td>
-    <td style="padding-right: 6px; padding-left: 6px; border-right: 1px solid #b8b8b8; white-space: nowrap;">optional</td>
-    <td style="padding-left: 6px; padding-right: 6px; white-space: nowrap;">read-only</td>
-</tr>
-</table>
-
-<p></p>
-
-=end markdown
-
 =head1 ENVIRONMENT VARIABLES
 
 =head2 FAKE_RELEASE
